## Books and Resources

-   [The Bash-Hackers Wiki](http://wiki.bash-hackers.org/doku.php) - Human-readable documentation of any kind about GNU Bash
-   [Bash beginner's mistakes](http://wiki.bash-hackers.org/scripting/newbie_traps) (by the Bash-Hackers Wiki)
-   [Bash Guide](http://mywiki.wooledge.org/BashGuide) - A bash guide for beginners. (by Lhunath)
-   [Bash FAQ](http://mywiki.wooledge.org/BashFAQ) - Answers most of your questions (by Lhunath)
-   [Bash Pitfalls](http://mywiki.wooledge.org/BashPitfalls) - Lists the common pitfalls beginners fall into, and how to avoid them
-   [Bash manual](http://www.gnu.org/software/bash/manual/) - Bourne-Again SHell manual
-   [Bash FAQ](http://tiswww.case.edu/php/chet/bash/FAQ) (by [Chet Ramey](http://tiswww.case.edu/php/chet/))
-   [Advanced Bash-Scripting Guide](http://tldp.org/LDP/abs/html/) - An in-depth exploration of the art of shell scripting
-   [Bash Guide for Beginners](http://www.tldp.org/LDP/Bash-Beginners-Guide/html/) (by Machtelt Garrels)
-   [Bash Programming - Intro/How-to](http://tldp.org/HOWTO/Bash-Prog-Intro-HOWTO.html#toc)
-   [bash-handbook](https://github.com/denysdovhan/bash-handbook) - A handbook for those who want to learn Bash without diving in too deeply
-   [Google's Shell Style Guide](https://google.github.io/styleguide/shell.xml)  - Reasonable advice about code style
-   [Sobell's Book](http://www.sobell.com/CR3/index.html) - A practical guide to commands, editors, and shell programming
-   [WikiBooks: Bash Shell Scripting](https://en.wikibooks.org/wiki/Bash_Shell_Scripting)
-   [Use the Unofficial Bash Strict Mode (Unless You Looove Debugging)](http://redsymbol.net/articles/unofficial-bash-strict-mode/)
-   [learnyoubash](https://github.com/denysdovhan/learnyoubash) - An interactive workshopper which will learn you how to use the terminal and write your the first Bash script.
- [Defensive BASH Programming](http://www.kfirlavi.com/blog/2012/11/14/defensive-bash-programming/) - Methods to defend your programs from breaking as well as keeping the code tidy and clean.
- [Pure Bash Bible](https://github.com/dylanaraps/pure-bash-bible) - A collection of pure bash alternatives to external processes.

## Command-Line Productivity

-   [aliases](https://github.com/sebglazebrook/aliases) - Contextual, dynamic, organized aliases for the bash shell
-   [bashhub](https://github.com/rcaloras/bashhub-client) - :cloud: Bash history in the cloud. Indexed and searchable.
-   [bashmarks](https://github.com/huyng/bashmarks) - Directory bookmarks for the shell
-   [commacd](https://github.com/shyiko/commacd) - A faster way to move around in Bash
-   [has](https://github.com/kdabir/has) - `has` helps you check presence of various command line tools and their versions on path
-   [hstr](https://github.com/dvorka/hstr) - Bash History Suggest Box
-   [qfc](https://github.com/pindexis/qfc) - File-completion widget for Bash and Zsh
-   [sshrc](https://github.com/Russell91/sshrc) - Bring your .bashrc, .vimrc, etc. with you when you SSH

## Customization

-   [bash-git-prompt](https://github.com/magicmonty/bash-git-prompt) - An informative and fancy Bash prompt for Git users
-   [bash-powerline](https://github.com/riobard/bash-powerline) - Powerline-style Bash prompt in pure Bash script
-   [bashstrap](https://github.com/barryclark/bashstrap) - A quick way to spruce up OSX terminal
-   [git-prompt](https://github.com/lvv/git-prompt) - Bash prompt with Git, SVN and HG modules
-   [gittify](https://github.com/momeni/gittify) - A colorful Bash prompt + customized Git aliases
-   [liquidprompt](https://github.com/nojhan/liquidprompt) - A full-featured & carefully designed adaptive prompt for Bash & Zsh
-   [mysql-colorize](https://github.com/horosgrisa/mysql-colorize.bash) -  Colorization for mysql comand-line client
-   [oh-my-git](https://github.com/arialdomartini/oh-my-git) - An opinionated git prompt for bash and zsh
-   [progress-bar.sh](https://github.com/edouard-lopez/progress-bar.sh) - Simple & sexy progressbar for `bash`, give it a duration and it will do the rest ![progress-bar.sh in action](http://pix.toile-libre.org/upload/original/1476311497.gif). 
-   [sexy-bash-prompt](https://github.com/twolfson/sexy-bash-prompt) - Bash prompt with colors, Git statuses, and Git branches
-   [bash-sensible](https://github.com/mrzool/bash-sensible) - An attempt at saner Bash defaults

## Data

-   [BigBash](https://github.com/zalando/bigbash) - Open-source converter that generates a bash one-liner from an SQL Select query, no database necessary

## Parsing Logs using Bash
- [Ultimate Guide to Logging and Bash Data Manipulation](https://www.loggly.com/ultimate-guide/analyzing-linux-logs/)
- [Using Grep & Regular Expressions to Search for Text Patterns in Linux](https://www.digitalocean.com/community/tutorials/using-grep-regular-expressions-to-search-for-text-patterns-in-linux#regular-expressions)

## For Developers

-   [bocker](https://github.com/p8952/bocker) - Docker implemented in 100 lines of bash
-   [git-sh](https://github.com/rtomayko/git-sh) - A customized Bash environment suitable for Git work

## Downloading and Serving

-   [balls](https://github.com/jneen/balls) - Bash on Balls
-   [bashttpd](https://github.com/avleen/bashttpd) - A web server written in Bash
-   [Dropbox-Uploader](https://github.com/andreafabrizi/Dropbox-Uploader) - Dropbox Uploader is a Bash script which can be used to upload, download, list or delete files from Dropbox
-   [ngincat](https://github.com/jaburns/ngincat) - Tiny Bash HTTP server using netcat
-   [xiringuito](https://github.com/ivanilves/xiringuito) - SSH-based VPN for poors

## Applications

-   [bashblog](https://github.com/cfenollosa/bashblog) - A Bash script that handles blog posting
-   [pushbullet-bash](https://github.com/Red5d/pushbullet-bash) - Bash interface to the PushBullet API
-   [todo.sh](https://github.com/todotxt/todo.txt-cli) - A simple and extensible shell script for managing your todo.txt file
-   [cheapci](https://github.com/ianmiell/cheapci) - A continuous integration framework implemented in bash

## Games

-   [bash2048](https://github.com/mydzor/bash2048) - Bash implementation of 2048 game
-   [minesweeper](https://github.com/feherke/Bash-script/tree/master/minesweeper) - Bash implementation of minesweeper
-   [solitaire](https://opensource-usability.blogspot.com/2016/10/solitaire-in-bash-script.html) - Bash implementation of solitaire

## Website

-   [Bash One-Liners](http://www.bashoneliners.com/) -  A collection of practical or just pure awesome bash one-liners ([repos](https://github.com/janosgyerik/bashoneliners) by @[janosgyerik](https://github.com/janosgyerik))
-   [commandlinefu](http://www.commandlinefu.com/) -  A repository for the most elegant and useful UNIX commands


## Shell Package Management

-   [bash-it](https://github.com/Bash-it/bash-it) - A community Bash framework
-   [basher](https://github.com/basherpm/basher) - A package manager for shell scripts
-   [bpkg](https://github.com/bpkg/bpkg) - A lightweight bash package manager
-   [homeshick](https://github.com/andsens/homeshick) - Git dotfile synchronizer written in Bash


## Shell Script Development

-   [ansi](https://github.com/fidian/ansi) - ANSI escape codes in pure bash - change text color, position the cursor, much more
-   [argbash](https://github.com/matejak/argbash) - Bash argument parsing code generator
-   [assert.sh](https://github.com/lehmannro/assert.sh) - Bash unit testing framework
-   [BashScriptTestingLibrary](https://github.com/rafritts/BashScriptTestingLibrary) - A unit testing framework for Bash scripts
-   [bash3boilerplate](https://github.com/kvz/bash3boilerplate) - Templates to write better Bash scripts
-   [bashful](https://github.com/jmcantrell/bashful) - A collection of libraries to simplify writing Bash scripts
-   [bashmanager](https://github.com/lingtalfi/bashmanager) - mini bash framework for creating command line tools
-   [bats](https://github.com/sstephenson/bats) - Bash Automated Testing System
-   [bash_unit](https://github.com/pgrange/bash_unit) -  bash unit testing enterprise edition framework for professionals 
-   [mo](https://github.com/tests-always-included/mo) - Mustache templates in pure bash
-   [semver_bash](https://github.com/cloudflare/semver_bash) - Semantic Versioning in Bash
-   [shfmt](https://github.com/mvdan/sh) - Format bash programs
-   [shunit2](https://github.com/kward/shunit2) - A unit test framework for Bash scripts with a flavour of JUnit/PyUnit
-   [bashing](https://github.com/xsc/bashing) - Smashing Bash into Pieces - Bash framework for creating command line tools
